@@ -1,7 +1,7 @@
 package Perinci::Sub::XCompletion;
 
-our $DATE = '2015-04-02'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2015-11-03'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 1;
 # ABSTRACT: Write completion routines in x.{element_,}completion attributes
@@ -18,14 +18,27 @@ Perinci::Sub::XCompletion - Write completion routines in x.{element_,}completion
 
 =head1 VERSION
 
-This document describes version 0.02 of Perinci::Sub::XCompletion (from Perl distribution Perinci-Sub-XCompletion), released on 2015-04-02.
+This document describes version 0.03 of Perinci::Sub::XCompletion (from Perl distribution Perinci-Sub-XCompletion), released on 2015-11-03.
+
+=head1 SYNOPSIS
+
+In L<Rinci> metadata:
+
+ args => {
+     foo => {
+         ...
+         'x.completion' => [filename => {file_regex_filter=>qr/\.(yaml|yml)$/i}],
+     },
+     ...
+ },
+ ...
 
 =head1 DESCRIPTION
 
 This is a module to support an experimental (and temporary?) way to ease writing
 completion routine. Instead of putting a coderef in C<completion> or
-C<element_completion> property in argument specification, you put C<<[$name,
-\%args]>> in C<x.completion> or C<x.element_completion> attributes. C<$name> is
+C<element_completion> property in argument specification, you put C<< [$name,
+\%args] >> in C<x.completion> or C<x.element_completion> attributes. C<$name> is
 the name of submodule to use, and \%args is arguments.
 
 =head1 SEE ALSO
